@@ -161,7 +161,7 @@ class Zone:
         This value is not available in the standard state poll response. The poll
         update frequency can be a little bit lower that expected.
         """
-        return self._device_conf()["Device"][f"FlowTemperatureZone{self.zone_index}"]
+        return self._device_conf()["Device"]["FlowTemperature"]
 
     @property
     def return_temperature(self) -> float:
@@ -170,7 +170,7 @@ class Zone:
         This value is not available in the standard state poll response. The poll
         update frequency can be a little bit lower that expected.
         """
-        return self._device_conf()["Device"][f"ReturnTemperatureZone{self.zone_index}"]
+        return self._device_conf()["Device"]["ReturnTemperature"]
 
     @property
     def target_flow_temperature(self) -> Optional[float]:
@@ -242,8 +242,14 @@ class Zone:
         if state is None:
             return None
 
+        print(state)
+
+        mode = state.get(f"OperationModeZone{self.zone_index}")
+        if not isinstance(mode, int):
+            raise ValueError(f"Invalid operation mode [{mode}]")
+
         return _ZONE_OPERATION_MODE_LOOKUP.get(
-            state.get(f"OperationModeZone{self.zone_index}"),
+            mode,
             ZONE_OPERATION_MODE_UNKNOWN,
         )
 
